@@ -39,7 +39,6 @@ VpncAuthDialog::VpncAuthDialog(const NetworkManager::VpnSetting::Ptr &setting, Q
     Q_D(VpncAuthDialog);
     d->ui.setupUi(this);
     d->setting = setting;
-    connect(d->ui.cbShowPasswords, &QCheckBox::toggled, this, &VpncAuthDialog::showPasswordsChanged);
 
     readSecrets();
 
@@ -95,10 +94,9 @@ void VpncAuthDialog::readSecrets()
     }
 }
 
-QVariantMap VpncAuthDialog::setting(bool agentOwned) const
+QVariantMap VpncAuthDialog::setting() const
 {
     Q_D(const VpncAuthDialog);
-    Q_UNUSED(agentOwned)
 
     NMStringMap secrets;
     QVariantMap result;
@@ -116,15 +114,3 @@ QVariantMap VpncAuthDialog::setting(bool agentOwned) const
 
     return result;
 }
-
-void VpncAuthDialog::showPasswordsChanged(bool show)
-{
-    Q_D(VpncAuthDialog);
-    if (show) {
-        d->ui.leUserPassword->setEchoMode(QLineEdit::Normal);
-        d->ui.leGroupPassword->setEchoMode(QLineEdit::Normal);
-    } else {
-        d->ui.leUserPassword->setEchoMode(QLineEdit::Password);
-        d->ui.leGroupPassword->setEchoMode(QLineEdit::Password);
-    }
-}
